"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.playwrightLauncher = void 0;
const playwright_1 = __importDefault(require("playwright"));
const constants_1 = require("../../core/constants");
const validBrowserTypes = ['chromium', 'firefox', 'webkit'];
function playwrightLauncher({ browserTypes = ['chromium'], } = {}) {
    const pages = new Map();
    if (browserTypes.some((t) => !validBrowserTypes.includes(t))) {
        throw new Error(`Invalid browser types: ${browserTypes}. Valid browser types: ${validBrowserTypes.join(', ')}`);
    }
    let config;
    let serverAddress;
    const browsers = new Map();
    return {
        async start(_config) {
            config = _config;
            serverAddress = `${config.address}:${config.port}/`;
            const browserNames = [];
            for (const type of browserTypes) {
                const name = `${type[0].toUpperCase()}${type.substring(1)}`;
                browserNames.push(name);
                const browser = await playwright_1.default[type].launch();
                browsers.set(name, browser);
            }
            return browserNames;
        },
        async stop() {
            for (const browser of browsers.values()) {
                await browser.close();
            }
        },
        async openDebugPage() {
            for (const browser of browsers.values()) {
                const page = await browser.newPage();
                await page.goto(`${serverAddress}debug/`);
            }
        },
        async startSession(session) {
            const browser = browsers.get(session.browserName);
            if (!browser) {
                throw new Error(`Unknown browser name: ${browser}`);
            }
            const page = await browser.newPage();
            pages.set(session.id, page);
            await page.goto(`${serverAddress}?${constants_1.PARAM_SESSION_ID}=${session.id}`);
        },
        stopSession(session) {
            const page = pages.get(session.id);
            if (page) {
                pages.delete(session.id);
                page.close();
            }
        },
    };
}
exports.playwrightLauncher = playwrightLauncher;
//# sourceMappingURL=playwright-launcher.js.map