"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.puppeteerLauncher = void 0;
const puppeteer_1 = require("puppeteer");
const constants_1 = require("../../core/constants");
function puppeteerLauncher({ args, } = {}) {
    const pages = new Map();
    let config;
    let serverAddress;
    let browser;
    let debugBrowser = undefined;
    return {
        async start(_config) {
            config = _config;
            browser = await puppeteer_1.launch({ args });
            serverAddress = `${config.address}:${config.port}/`;
            return ['Chrome'];
        },
        async stop() {
            if (browser.isConnected()) {
                await browser.close();
            }
            if (debugBrowser === null || debugBrowser === void 0 ? void 0 : debugBrowser.isConnected()) {
                await debugBrowser.close();
            }
        },
        async openDebugPage() {
            debugBrowser = await puppeteer_1.launch({ args, devtools: true });
            const page = await debugBrowser.newPage();
            await page.goto(`${serverAddress}debug/`);
        },
        async startSession(session) {
            const page = await browser.newPage();
            pages.set(session.id, page);
            await page.goto(`${serverAddress}?${constants_1.PARAM_SESSION_ID}=${session.id}`);
        },
        stopSession(session) {
            const page = pages.get(session.id);
            if (page) {
                pages.delete(session.id);
                page.close();
            }
        },
    };
}
exports.puppeteerLauncher = puppeteerLauncher;
//# sourceMappingURL=puppeteer-launcher.js.map